web

package
v0.31.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 21, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func RegisterRoutes

func RegisterRoutes(mux *http.ServeMux) error

RegisterRoutes registers the web UI routes on the given ServeMux. Serves the embedded static files at the root path. Returns an error if the embedded filesystem cannot be loaded.

Types

This section is empty.

Jump to