Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Agent ¶
type Agent interface {
// Name returns the agent's identifier.
Name() string
// Start begins the agent's work. Should be non-blocking (launch goroutines).
Start(ctx context.Context, bus events.Bus) error
// Stop gracefully stops the agent.
Stop() error
// Health checks if the agent is functioning.
Health(ctx context.Context) error
}
Agent is the base interface for all cognitive layer agents.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package forum provides agent personality templates for forum communication.
|
Package forum provides agent personality templates for forum communication. |
Click to show internal directories.
Click to hide internal directories.